@@ -291,6 +291,27 @@ DEBUG_OPTIONS = ["subcommand", "sidecar", "s3client"]
 for typ in DEBUG_OPTIONS:
     vars()["DEBUG_%s" % typ.upper()] = from_conf("DEBUG_%s" % typ.upper())
 
+###
+# Plugin configuration
+###
+
+# Plugin configuration variables exist in plugins/__init__.py.
+# Specifically, there is an ENABLED_<category> configuration value to determine
+# the set of plugins to enable. The categories are: step_decorator, flow_decorator,
+# environment, metadata_provider, datastore, sidecar, logging_sidecar, monitor_sidecar,
+# aws_client_provider, and cli. If not set (the default), all plugins are enabled.
+# You can restrict which plugins are enabled by listing them explicitly, for example
+# ENABLED_STEP_DECORATOR = ["batch", "resources"] will enable only those two step
+# decorators and none other.
+
+###
+# Command configuration
+###
+
+# Command (ie: metaflow <cmd>) configuration variable ENABLED_CMD
+# exists in cmd/main_cli.py. It behaves just like any of the other ENABLED_<category>
+# configuration variables.
+
 ###
 # AWS Sandbox configuration
 ###
@@ -314,11 +335,11 @@ if AWS_SANDBOX_ENABLED:
     SFN_STATE_MACHINE_PREFIX = from_conf("AWS_SANDBOX_STACK_NAME")
 
 KUBERNETES_SANDBOX_INIT_SCRIPT = from_conf("KUBERNETES_SANDBOX_INIT_SCRIPT")
-KUBERNETES_SANDBOX_INIT_SCRIPT = from_conf("METAFLOW_KUBERNETES_SANDBOX_INIT_SCRIPT")
-MAX_MEMORY_PER_TASK = from_conf("METAFLOW_MAX_MEMORY_PER_TASK")
-MAX_CPU_PER_TASK = from_conf("METAFLOW_MAX_CPU_PER_TASK")
 
-OTEL_ENDPOINT = from_conf("METAFLOW_OTEL_ENDPOINT")
+MAX_MEMORY_PER_TASK = from_conf("MAX_MEMORY_PER_TASK")
+MAX_CPU_PER_TASK = from_conf("MAX_CPU_PER_TASK")
+
+OTEL_ENDPOINT = from_conf("OTEL_ENDPOINT")
 
 # MAX_ATTEMPTS is the maximum number of attempts, including the first
 # task, retries, and the final fallback task and its retries.
@@ -409,7 +430,7 @@ finally:
         "m",
         "n",
         "o",
-        "type",
+        "typ",
         "ext_modules",
         "get_modules",
         "_new_get_pinned_conda_libs",
